@@ -2,7 +2,6 @@ import os
 import base64
 
 import requests
-from attrdict import AttrDict
 
 from json.decoder import JSONDecodeError
 
@@ -42,7 +41,7 @@ class MandrillEmailBackend(EmailBackend):
         MandrillState.INVALID: EmailMessageState.ERROR,
     }
 
-    config = AttrDict({
+    config = {
         'HEADERS': None,
         'TRACK_OPENS': False,
         'TRACK_CLICKS': False,
@@ -53,7 +52,7 @@ class MandrillEmailBackend(EmailBackend):
         'VIEW_CONTENT_LINK': True,
         'ASYNC': False,
         'TIMEOUT': 5,  # 5s
-    })
+    }
 
     def _serialize_attachments(self, message):
         return [
@@ -65,11 +64,11 @@ class MandrillEmailBackend(EmailBackend):
         ]
 
     def _create_client(self, message):
-        mandrill_client = mandrill.Mandrill(self.config.KEY)
+        mandrill_client = mandrill.Mandrill(self.config['KEY'])
         mandrill_client.session = generate_session(
             slug='pymess - Mandrill',
             related_objects=(message,),
-            timeout=self.config.TIMEOUT
+            timeout=self.config['TIMEOUT']
         )
         return mandrill_client
 
@@ -83,14 +82,14 @@ class MandrillEmailBackend(EmailBackend):
                     'from_name': message.sender_name,
                     'html': message.content,
                     'subject': message.subject,
-                    'headers': self.config.HEADERS,
-                    'track_opens': self.config.TRACK_OPENS,
-                    'auto_text': self.config.AUTO_TEXT,
-                    'inline_css': self.config.INLINE_CSS,
-                    'url_strip_qs': self.config.URL_STRIP_QS,
-                    'preserve_recipients': self.config.PRESERVE_RECIPIENTS,
-                    'view_content_link': self.config.VIEW_CONTENT_LINK,
-                    'async': self.config.ASYNC,
+                    'headers': self.config['HEADERS'],
+                    'track_opens': self.config['TRACK_OPENS'],
+                    'auto_text': self.config['AUTO_TEXT'],
+                    'inline_css': self.config['INLINE_CSS'],
+                    'url_strip_qs': self.config['URL_STRIP_QS'],
+                    'preserve_recipients': self.config['PRESERVE_RECIPIENTS'],
+                    'view_content_link': self.config['VIEW_CONTENT_LINK'],
+                    'async': self.config['ASYNC'],
                     'attachments': self._serialize_attachments(message)
                 },
             )[0]
