@@ -8,4 +8,4 @@ class DummySMSBackend(SMSBackend):
     """
 
     def publish_message(self, message):
-        self._update_message_after_sending(message, state=message.STATE.DEBUG, sent_at=timezone.now())
+        self._update_message_after_sending(message, state=message.State.DEBUG, sent_at=timezone.now())
